package com.mall.member.controller;

import com.mall.member.domain.dto.MemberCollectSpuDto;
import com.mall.member.domain.entity.MemberCollectSpu;
import com.mall.member.domain.vo.MemberCollectSpuVo;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import com.mall.member.service.MemberCollectSpuService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 会员收藏的商品 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 19:30:06
 */
@Tag(name = "会员收藏的商品", description = "会员收藏的商品相关接口")
@RestController
@RequestMapping("/api/member/member-collect-spu")
@RequiredArgsConstructor
public class MemberCollectSpuController {

    private final MemberCollectSpuService memberCollectSpuService;

    @Operation(summary = "分页查询会员收藏的商品", description = "分页会员收藏的商品")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<MemberCollectSpuVo>> getMemberCollectSpuPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            MemberCollectSpuDto dto) {
        Page<MemberCollectSpu> pageParams = new Page<>(page, limit);
        PageResult<MemberCollectSpuVo> pageResult = memberCollectSpuService.getMemberCollectSpuPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加会员收藏的商品", description = "添加会员收藏的商品")
    @PostMapping()
    public Result<String> addMemberCollectSpu(@Valid @RequestBody MemberCollectSpuDto dto) {
            memberCollectSpuService.addMemberCollectSpu(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新会员收藏的商品", description = "更新会员收藏的商品")
    @PutMapping()
    public Result<String> updateMemberCollectSpu(@Valid @RequestBody MemberCollectSpuDto dto) {
            memberCollectSpuService.updateMemberCollectSpu(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除会员收藏的商品", description = "删除会员收藏的商品")
    @DeleteMapping()
    public Result<String> deleteMemberCollectSpu(@RequestBody List<Long> ids) {
            memberCollectSpuService.deleteMemberCollectSpu(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}