package com.mall.member.controller;

import com.mall.member.domain.dto.MemberLevelDto;
import com.mall.member.domain.entity.MemberLevel;
import com.mall.member.domain.vo.MemberLevelVo;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import com.mall.member.service.MemberLevelService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 会员等级 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 19:30:06
 */
@Tag(name = "会员等级", description = "会员等级相关接口")
@RestController
@RequestMapping("/api/member/member-level")
@RequiredArgsConstructor
public class MemberLevelController {

    private final MemberLevelService memberLevelService;

    @Operation(summary = "分页查询会员等级", description = "分页会员等级")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<MemberLevelVo>> getMemberLevelPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            MemberLevelDto dto) {
        Page<MemberLevel> pageParams = new Page<>(page, limit);
        PageResult<MemberLevelVo> pageResult = memberLevelService.getMemberLevelPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加会员等级", description = "添加会员等级")
    @PostMapping()
    public Result<String> addMemberLevel(@Valid @RequestBody MemberLevelDto dto) {
            memberLevelService.addMemberLevel(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新会员等级", description = "更新会员等级")
    @PutMapping()
    public Result<String> updateMemberLevel(@Valid @RequestBody MemberLevelDto dto) {
            memberLevelService.updateMemberLevel(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除会员等级", description = "删除会员等级")
    @DeleteMapping()
    public Result<String> deleteMemberLevel(@RequestBody List<Long> ids) {
            memberLevelService.deleteMemberLevel(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}