package com.mall.member.controller;

import com.mall.member.domain.dto.MemberReceiveAddressDto;
import com.mall.member.domain.entity.MemberReceiveAddress;
import com.mall.member.domain.vo.MemberReceiveAddressVo;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import com.mall.member.service.MemberReceiveAddressService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 会员收货地址 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 19:30:06
 */
@Tag(name = "会员收货地址", description = "会员收货地址相关接口")
@RestController
@RequestMapping("/api/member/member-receive-address")
@RequiredArgsConstructor
public class MemberReceiveAddressController {

    private final MemberReceiveAddressService memberReceiveAddressService;

    @Operation(summary = "分页查询会员收货地址", description = "分页会员收货地址")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<MemberReceiveAddressVo>> getMemberReceiveAddressPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            MemberReceiveAddressDto dto) {
        Page<MemberReceiveAddress> pageParams = new Page<>(page, limit);
        PageResult<MemberReceiveAddressVo> pageResult = memberReceiveAddressService.getMemberReceiveAddressPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加会员收货地址", description = "添加会员收货地址")
    @PostMapping()
    public Result<String> addMemberReceiveAddress(@Valid @RequestBody MemberReceiveAddressDto dto) {
            memberReceiveAddressService.addMemberReceiveAddress(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新会员收货地址", description = "更新会员收货地址")
    @PutMapping()
    public Result<String> updateMemberReceiveAddress(@Valid @RequestBody MemberReceiveAddressDto dto) {
            memberReceiveAddressService.updateMemberReceiveAddress(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除会员收货地址", description = "删除会员收货地址")
    @DeleteMapping()
    public Result<String> deleteMemberReceiveAddress(@RequestBody List<Long> ids) {
            memberReceiveAddressService.deleteMemberReceiveAddress(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}