package com.mall.member.service.impl;

import com.mall.member.mapper.MemberCollectSubjectMapper;
import com.mall.member.service.MemberCollectSubjectService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.member.service.MemberCollectSubjectService;
import com.mall.member.domain.dto.MemberCollectSubjectDto;
import com.mall.member.domain.entity.MemberCollectSubject;
import com.mall.member.domain.vo.MemberCollectSubjectVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 会员收藏的专题活动 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 19:30:06
 */
@Service
@Transactional
public class MemberCollectSubjectServiceImpl extends ServiceImpl<MemberCollectSubjectMapper, MemberCollectSubject> implements MemberCollectSubjectService {

    /**
     * * 会员收藏的专题活动 服务实现类
     *
     * @param pageParams 会员收藏的专题活动分页查询page对象
     * @param dto        会员收藏的专题活动分页查询对象
     * @return 查询分页会员收藏的专题活动返回对象
     */
    @Override
    public PageResult<MemberCollectSubjectVo> getMemberCollectSubjectPage(Page<MemberCollectSubject> pageParams, MemberCollectSubjectDto dto) {
        IPage<MemberCollectSubjectVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<MemberCollectSubjectVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加会员收藏的专题活动
     *
     * @param dto 会员收藏的专题活动添加
     */
    @Override
    public void addMemberCollectSubject(MemberCollectSubjectDto dto) {
        MemberCollectSubject memberCollectSubject =new MemberCollectSubject();
        BeanUtils.copyProperties(dto, memberCollectSubject);
        save(memberCollectSubject);
    }

    /**
     * 更新会员收藏的专题活动
     *
     * @param dto 会员收藏的专题活动更新
     */
    @Override
    public void updateMemberCollectSubject(MemberCollectSubjectDto dto) {
        MemberCollectSubject memberCollectSubject =new MemberCollectSubject();
        BeanUtils.copyProperties(dto, memberCollectSubject);
        updateById(memberCollectSubject);
    }

    /**
     * 删除|批量删除会员收藏的专题活动
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteMemberCollectSubject(List<Long> ids) {
        removeByIds(ids);
    }
}