package com.mall.order.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.order.domain.dto.OrderItemDto;
import com.mall.order.domain.entity.OrderItem;
import com.mall.order.domain.vo.OrderItemVo;
import com.mall.order.mapper.OrderItemMapper;
import com.mall.order.service.OrderItemService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 订单项信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-05 18:54:06
 */
@Service
@Transactional
public class OrderItemServiceImpl extends ServiceImpl<OrderItemMapper, OrderItem> implements OrderItemService {

    /**
     * * 订单项信息 服务实现类
     *
     * @param pageParams 订单项信息分页查询page对象
     * @param dto        订单项信息分页查询对象
     * @return 查询分页订单项信息返回对象
     */
    @Override
    public PageResult<OrderItemVo> getOrderItemPage(Page<OrderItem> pageParams, OrderItemDto dto) {
        IPage<OrderItemVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<OrderItemVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加订单项信息
     *
     * @param dto 订单项信息添加
     */
    @Override
    public void addOrderItem(OrderItemDto dto) {
        OrderItem orderItem = new OrderItem();
        BeanUtils.copyProperties(dto, orderItem);
        save(orderItem);
    }

    /**
     * 更新订单项信息
     *
     * @param dto 订单项信息更新
     */
    @Override
    public void updateOrderItem(OrderItemDto dto) {
        OrderItem orderItem = new OrderItem();
        BeanUtils.copyProperties(dto, orderItem);
        updateById(orderItem);
    }

    /**
     * 删除|批量删除订单项信息
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteOrderItem(List<Long> ids) {
        removeByIds(ids);
    }
}