package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.AttrDto;
import com.mall.product.domain.entity.Attr;
import com.mall.product.domain.vo.AttrVo;
import com.mall.product.mapper.AttrMapper;
import com.mall.product.service.AttrService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 商品属性 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class AttrServiceImpl extends ServiceImpl<AttrMapper, Attr> implements AttrService {

    /**
     * * 商品属性 服务实现类
     *
     * @param pageParams 商品属性分页查询page对象
     * @param dto        商品属性分页查询对象
     * @return 查询分页商品属性返回对象
     */
    @Override
    public PageResult<AttrVo> getAttrPage(Page<Attr> pageParams, AttrDto dto) {
        IPage<AttrVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<AttrVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品属性
     *
     * @param dto 商品属性添加
     */
    @Override
    public void addAttr(AttrDto dto) {
        Attr attr = new Attr();
        BeanUtils.copyProperties(dto, attr);
        save(attr);
    }

    /**
     * 更新商品属性
     *
     * @param dto 商品属性更新
     */
    @Override
    public void updateAttr(AttrDto dto) {
        Attr attr = new Attr();
        BeanUtils.copyProperties(dto, attr);
        updateById(attr);
    }

    /**
     * 删除|批量删除商品属性
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteAttr(List<Long> ids) {
        removeByIds(ids);
    }
}