package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.SkuInfoDto;
import com.mall.product.domain.entity.SkuInfo;
import com.mall.product.domain.vo.SkuInfoVo;
import com.mall.product.mapper.SkuInfoMapper;
import com.mall.product.service.SkuInfoService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * sku信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class SkuInfoServiceImpl extends ServiceImpl<SkuInfoMapper, SkuInfo> implements SkuInfoService {

    /**
     * * sku信息 服务实现类
     *
     * @param pageParams sku信息分页查询page对象
     * @param dto        sku信息分页查询对象
     * @return 查询分页sku信息返回对象
     */
    @Override
    public PageResult<SkuInfoVo> getSkuInfoPage(Page<SkuInfo> pageParams, SkuInfoDto dto) {
        IPage<SkuInfoVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SkuInfoVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加sku信息
     *
     * @param dto sku信息添加
     */
    @Override
    public void addSkuInfo(SkuInfoDto dto) {
        SkuInfo skuInfo = new SkuInfo();
        BeanUtils.copyProperties(dto, skuInfo);
        save(skuInfo);
    }

    /**
     * 更新sku信息
     *
     * @param dto sku信息更新
     */
    @Override
    public void updateSkuInfo(SkuInfoDto dto) {
        SkuInfo skuInfo = new SkuInfo();
        BeanUtils.copyProperties(dto, skuInfo);
        updateById(skuInfo);
    }

    /**
     * 删除|批量删除sku信息
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSkuInfo(List<Long> ids) {
        removeByIds(ids);
    }
}